aboutsummaryrefslogtreecommitdiff
path: root/cast/sender/cast_platform_client.h
diff options
context:
space:
mode:
Diffstat (limited to 'cast/sender/cast_platform_client.h')
-rw-r--r--cast/sender/cast_platform_client.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/cast/sender/cast_platform_client.h b/cast/sender/cast_platform_client.h
index 8ea9a99a..c80a8b95 100644
--- a/cast/sender/cast_platform_client.h
+++ b/cast/sender/cast_platform_client.h
@@ -20,7 +20,7 @@
namespace openscreen {
namespace cast {
-struct ServiceInfo;
+struct ReceiverInfo;
class VirtualConnectionRouter;
// This class handles Cast messages that generally relate to the "platform", in
@@ -41,15 +41,15 @@ class CastPlatformClient final : public CastMessageHandler {
~CastPlatformClient() override;
// Requests availability information for |app_id| from the receiver identified
- // by |device_id|. |callback| will be called exactly once with a result.
- absl::optional<int> RequestAppAvailability(const std::string& device_id,
+ // by |receiver_id|. |callback| will be called exactly once with a result.
+ absl::optional<int> RequestAppAvailability(const std::string& receiver_id,
const std::string& app_id,
AppAvailabilityCallback callback);
// Notifies this object about general receiver connectivity or property
// changes.
- void AddOrUpdateReceiver(const ServiceInfo& device, int socket_id);
- void RemoveReceiver(const ServiceInfo& device);
+ void AddOrUpdateReceiver(const ReceiverInfo& receiver, int socket_id);
+ void RemoveReceiver(const ReceiverInfo& receiver);
void CancelRequest(int request_id);
@@ -70,7 +70,7 @@ class CastPlatformClient final : public CastMessageHandler {
CastSocket* socket,
::cast::channel::CastMessage message) override;
- void HandleResponse(const std::string& device_id,
+ void HandleResponse(const std::string& receiver_id,
int request_id,
const Json::Value& message);
@@ -82,9 +82,9 @@ class CastPlatformClient final : public CastMessageHandler {
const std::string sender_id_;
VirtualConnectionRouter* const virtual_conn_router_;
- std::map<std::string /* device_id */, int> socket_id_by_device_id_;
- std::map<std::string /* device_id */, PendingRequests>
- pending_requests_by_device_id_;
+ std::map<std::string /* receiver_id */, int> socket_id_by_receiver_id_;
+ std::map<std::string /* receiver_id */, PendingRequests>
+ pending_requests_by_receiver_id_;
const ClockNowFunctionPtr clock_;
TaskRunner* const task_runner_;